@@ -44,8 +44,8 @@ GIT_ABBREV_LENGTH = 12
 # If the text "$Format" is still present, it means that
 # git archive did not replace the $Format string, which
 # means that this not a git archive.
-GIT_EXPORT_SUBST_H = '415456d133701e83d2f0aac3d90f26879fb3dad1'
-GIT_EXPORT_SUBST_D = 'tag: wireshark-4.0.2, tag: v4.0.2, refs/pipelines/716370832, refs/merge-requests/9039/head, refs/keep-around/415456d133701e83d2f0aac3d90f26879fb3dad1'
+GIT_EXPORT_SUBST_H = 'c552f74cdc235956749afb80f6536ca8c9c145d7'
+GIT_EXPORT_SUBST_D = 'tag: wireshark-4.0.3, tag: v4.0.3, refs/merge-requests/9517/head, refs/keep-around/c552f74cdc235956749afb80f6536ca8c9c145d7'
 IS_GIT_ARCHIVE = not GIT_EXPORT_SUBST_H.startswith('$Format')
 
 
